package de.klawitter.android.widget;

import android.content.Context;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;
import android.widget.LinearLayout;

/**
 * If you want to place a view at the bottom of a screen, you can use
 * this FooterLayout to do so.
 * <p>
 * FooterLayout expects two child views:
 * <ul>
 * <li>The "center" of the view. (Typically a ScrollView)
 * <li>The "footer" of the view.
 * </ul>
 * The footer will be placed at the bottom of the view, andthe center
 * will consume the rest of the height.
 * 
 * @author <a href="mailto:info-android@klawitter.de">Holger Klawitter</a>
 */
public class FooterLayout extends LinearLayout {

	public FooterLayout(Context context, AttributeSet attrs) {
		super(context, attrs);
	}

	private int footerHeight;
	
	@Override 
	protected void onMeasure( int wSpec, int hSpec ) {
		int len = getChildCount();
		if( len!=2 ) throw new IllegalArgumentException( "FooterLayout needs exactly two children" ); 

		View center = getChildAt(0);
		View footer = getChildAt(1);

		measureChildWithMargins(footer, wSpec, 0, hSpec, 0);
		footerHeight = footer.getMeasuredHeight();

		measureChildWithMargins(center, wSpec, 0, hSpec-footerHeight, 0);

		setMeasuredDimension( MeasureSpec.getSize(wSpec), MeasureSpec.getSize(hSpec) );
	}

	@Override
	protected void onLayout( boolean changed, int l, int t, int r, int b ) {
		int pLeft = getPaddingLeft();
		int pTop = getPaddingTop();

		int w = r-l-pLeft-getPaddingRight(); 
		int h = b-t-pTop-getPaddingBottom();

		View center = getChildAt(0);
		View footer = getChildAt(1);

		center.layout( pLeft, pTop, w + pLeft, h - footerHeight + pTop);
		footer.layout( pLeft, h - footerHeight + pTop , w + pLeft, h + pTop);
	}

}
